# MATILS Utility Library

The Matils Library is intend to have utility modules, classes and functions
that are not found in Python's Standard Library. It focus also on offering
the implementation of Design Patterns. 

Enjoy!

## List of Utilities!

    * Observer/Observable Pattern
